#RequireAdmin
#Region ;**** Directives created by AutoIt3Wrapper_GUI ****
#AutoIt3Wrapper_icon=lili.ico
#AutoIt3Wrapper_UseUpx=n
#EndRegion ;**** Directives created by AutoIt3Wrapper_GUI ****
; Author      : Thibaut Lauziere
; Contact     : FS306@linuxliveusb.com
; Licence     : GPL v3
; Description : Cleans your registry of any disks having the LiLi's icon.
; Disclaimer  : This script is provided AS IS under GPL v3 Licence terms.

#include <GUIConstantsEx.au3>
#include <WindowsConstants.au3>
#include <GuiConstants.au3>
#include <Constants.au3>
#include <ProgressConstants.au3>
#include <ComboConstants.au3>
#include <ButtonConstants.au3>
#include <StaticConstants.au3>
#include <EditConstants.au3>
#include <File.au3>

Global $dir = @ScriptDir&"\"&@YEAR& "-" & @MON & "-" & @MDAY &" @ "&@HOUR&"h"&@MIN&"s"&@SEC&"\"

DirCreate($dir)

;ExportKey("HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\Explorer\DriveIcons","DriveIcons_"&@YEAR& "-" & @MON & "-" & @MDAY &"_"&@HOUR&"-"&@MIN&"-"&@SEC&".reg")
ExportKey("HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Explorer\MountPoints2","MountPoints2.reg")

if FileExists($dir&"MountPoints2.reg") Then
	UpdateLog("Backup of MountPoints2 successfully created")
Else
	UpdateLog("Could not backup MountPoints2 hive, stopping now")
	MsgBox(16,"Error","Could not backup MountPoints2 hive, stopping now")
	Exit
EndIf


$start_hive="HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Explorer\MountPoints2"
UpdateLog("Enumerating keys in "&$start_hive)

$cleaned=0
$error=0
$found=0

For $i= 1 to 1000
    $var = RegEnumKey($start_hive, $i)
    If @error <> 0 then ExitLoop
	if StringInStr(RegRead($start_hive&"\"&$var&"\_Autorun\DefaultIcon",""),"lili.ico") Then
		$found+=1
		UpdateLog("Found a key with a LiLi logo :"&$var)
		$delete_return = RegDelete($start_hive&"\"&$var)

		if $delete_return AND RegRead($start_hive&"\"&$var&"\_Autorun\DefaultIcon","")="" Then
			$cleaned+=1
			UpdateLog("Key using LiLi's logo "&$var&" has been successfully deleted")
		Else
			UpdateLog("Key using LiLi's logo "&$var&" could not be deleted")
			$error+=1
		EndIf
	EndIf
Next

if $found=$cleaned Then
	$append_msg="Everything should be fine now. Open an explorer and check."
Else
	$append_msg="There was some errors. Please contact FS304@linuxliveusb.com and attach the log file."
EndIf

$completion_report="This is a completion report."&@CRLF&@CRLF&$found&" key using LiLi's logo have been found."&@CRLF&$cleaned&" keys have been cleaned."&@CRLF&$error&" could not be cleaned."&@CRLF&@CRLF&$append_msg

UpdateLog("Completion Report"&@CRLF&$completion_report)

MsgBox(64,"Completion Report",$completion_report)


Func ExportKey($key,$tofile)
	UpdateLog("Exporting Key "&$key& " to file "&$tofile  )
	if get_extension($tofile) <> "reg" Then $tofile=$tofile&".reg"
	$cmd='REG EXPORT '&$key&' "'& $tofile & '"'
	ExecuteCommand($cmd)
EndFunc

Func RestoreKey($tofile)
	if get_extension($tofile) <> "reg" Then $tofile=$tofile&".reg"
	$cmd='REG IMPORT "'& $tofile &'"'
	ExecuteCommand($cmd)
EndFunc

Func ExecuteCommand($cmd)
	UpdateLog("Running command "&$cmd )
	$foo = Run($cmd, $dir, @SW_HIDE, $STDOUT_CHILD + $STDERR_CHILD)
	$line = ""
	While True
		$line &= StdoutRead($foo)
		If @error Then ExitLoop
		$line &= StderrRead($foo)
		If @error Then ExitLoop
		Sleep(300)
	WEnd
	UpdateLog("Result of command is :"&@CRLF&$line)
EndFunc

Func get_extension($filepath)
	$short_name = StringSplit($filepath, '.')
	Return ($short_name[$short_name[0]])
EndFunc

Func UpdateLog($status)
	_FileWriteLog($dir&"log.txt",$status)
EndFunc